# Release 0.5.4

Please see the [Release 0.5.0 release notes](v0_5_0.md) for details on the first cut.

Patches on top of v0.5.0 involve fixing our deployment pipeline.

## Patches
```
6607e82 docs: Release notes for release 0.5.3
a12fe9c ci/cd: Update description key in setup.cfg
74cc9fb docs: Release notes for release 0.5.2
ee99d6a ci/cd: Fix typo in pypirc file
6db943d docs: Release notes for release 0.5.1
28d7683 ci/cd: Remove 'verify' custom command
```
